#ILLiad Reshare DSP Addon 

##Overview

The ILLiad Reshare addon is a Decision Support Pipeline (DSP) server addon that helps automate fulfillment through the Reshare service. It will process ILLiad requests placed in the Loan DSP pipeline or in a specified search queue, automatically initiate a Reshare request if appropriate, and poll the status of the Reshare request to automatically complete the ILLiad request or otherwise indicate it is unfilled.

##Settings

###NVTGC
This setting should be the same as the NVTGC this addon is configured under in Customization Manager. It is used to filter requests that should be processed from the **SearchingMonitorQueue**. This is particularly important for shared server setups.
Default: **ILL**

###SharedIndexAPIUrl
The URL for the Shared Index API service.

###SharedIndexUsername
The username to use when authenticating against the Shared Index API service.

###SharedIndexPassword
The password to use when authenticating against the Shared Index API service.

###SharedIndexTenant
Your institution's tenant ID for the Shared Index API service.

###ReshareAPIUrl
The URL for the Reshare API service.

###ReshareAPIUsername
The username to use when authenticating against the Reshare API service.

###ReshareAPIPassword
The password to use when authenticating against the Reshare API service.

###ReshareTenant
Your institution's tenant ID or SLUG for the Reshare API service.

###OpenURLListenerURL
The OpenURL endpoint used to create requests in Reshare.

###OpenURLTenant
Your institution's symbol for the Reshare OpenURL endpoint.

###SearchingMonitorQueue
This defines the ILLiad status that the addon will monitor for requests that the addon should try to fulfill through Reshare.
Default: **Awaiting Reshare Search**

###NotFoundQueue
This defines the ILLiad status that requests will be routed to when a single requestable item is not found in Reshare.
Default: **Awaiting Request Processing**

###UnfilledQueue
This defines the ILLiad status that requests will be routed to when they are marked unfilled in Reshare.
Default: **Awaiting Unfilled Processing**

###RequestSentQueue
This defines the ILLiad status that requests will be routed to when they are successfully requested in Reshare.
Default: **Request Sent**


###PatronIDField
The value to use to identify who the request is for. This field supports table tags and will use the ILLiad request's username by default.
Default: **{TableField:User.Username}**

###PickupLocationLookupValue
The value to use to identify a pickup location value of the request. This field supports table tags and will use the NVTGC of the owner of the ILLiad request by default. This value can then be used to lookup the Reshare pickup location code from the PickupLocationLookupMapping setting.
Default: **{TableField:User.NVTGC}**

###PickupLocationLookupMapping
This defines a comma-separated mapping that defines the Reshare pickup location or LMS location code to use for a given PickupLocationLookupValue, determined from the prior setting. If this mapping does not contain a key for the provided lookup value, the lookup value will be used without modification.
Example: **ILL=DEFAULT_CIRC_DESK**

###RequestPollingFrequency
This defines how frequently, in minutes, the addon will poll the Reshare service for status updates on submitted requests. 
Default: **10**

###ReshareFilledStatuses
A comma-separated list of the Reshare states that are considered to be filled.
Default: **REQ_SHIPPED**

###ReshareUnfilledStatuses
A comma-separated list of the Reshare states that are considered to be unfilled.
Default: **REQ_END_OF_ROTA, REQ_UNABLE_TO_CONTACT_SUPPLIER**

##Workflow

###Decision Support Pipline

####Stage 2
The addon looks at requests in the **Awaiting Request Pipeline** status and checks the Reshare Index to see if it can be found in the Shared Index. It will search for requests using bibliographic data with the following precedence:
1. by OCLC number if the ILLiad request has a value in ESPNumber.
2. by ISBN if the ILLiad request has a value in ISSN.
3. by title, author, and date using the LoanTitle, LoanAuthor, and LoanDate fields.

If a single result is found in this step, the ILLiad request is routed to **Awaiting Pipeline Sending** and proceeds to Stage 3. If zero or more than one results are found, the ILLiad request is routed to **Awaiting Pipeline Request Review** for manual processing.

####Stage 3
The addon looks at request in the **Awaiting Pipeline Sending** and submits a Reshare request for the ILLiad request. This step determines the patron identifier and pickup location used for the Reshare Request using the **PatronIDField**, **PickupLocationLookupValue**, and **PickupLocationLookupMapping** settings. The ILLiad request is then routed to the status **RequestSentQueue**.

###Search Queue
The addon also monitors the ILLiad status defined in the **SearchingMonitorQueue** setting. Requests in this queue are first confirmed that they are within the addon's scope by checking their user's NVTGC and confirming it's under the addon's **NVTGC** setting. Then, the Reshare Index is searched and the Reshare request is created in the same manner as in the DSP pipeline. Once requested, the ILLiad request is routed to **RequestSentQueue**. If the Reshare request cannot be created because there are no matching items, or more than one matching item, the ILLiad request is routed to the status **NotFoundQueue**.

###Request Status Polling
The addon will poll the Reshare service to check the current state of requests and will automatically update their corresponding ILLiad requests. The frequency of the polling interval is defined in the **RequestPollingFrequency** setting, in minutes. Note that addon cannot poll Reshare faster than its System Manager interval, defined in the **SystemManagerAddonInterval** customization key.

It first starts with the states defined in the **ReshareUnfilledStatuses** setting. It retrieves all Reshare requests in this state and, for each one, checks to see if their is a corresponding ILLiad request with a matching ILLNumber field, and updates those reqeusts to **UnfilledQueue**. It then does the same for states defined in **ReshareFilledStatuses**, routing the ILLiad requests to **Request Finished**.
